==> pytone_2.0.13.orig.tar.gz: PyTone-2.0.13/src/services/players/remote.py <==
# -*- coding: ISO-8859-1 -*-

# Copyright (C) 2003 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyX; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import copy, threading
import hub, events, requests
import network

class player(threading.Thread):
    def __init__(self, id, server, port):
        threading.Thread.__init__(self)
        self.id = id
        self.server = server
        self.port = port
        self.remoteplayerid = "main"

        # as independent thread, we want our own event channel
        self.channel = hub.hub.newchannel()

        self.networkchannel = network.tcpclientchannel(self.server, self.port)
        #self.networkchannel.transmit(events.updatesong)
        #self.networkchannel.transmit(events.updatealbum)
        #self.networkchannel.transmit(events.updateartist)
        #self.networkchannel.transmit(events.playlistaddsong)
        self.networkchannel.subscribe(events.playbackinfochanged, self.playbackinfochanged)

        # for playlists
        self.networkchannel.subscribe(events.playlistchanged, self.playlistchanged)
        self.networkchannel.start()

        self.done = 0

        # we are only servants of higher powers
        self.setDaemon(1)

        # provide player service
        self.channel.subscribe(events.playerevent, self.playerevent)
        # self.channel.subscribe(events.nextsong, self.playerevents)
        
        # we also provide a playlist service
        self.channel.subscribe(events.playlistevent, self.playlistevent)
        self.channel.supply(requests.playlistgetcontents, self.playlistgetcontents)
        
        self.channel.subscribe(events.quit, self.quit)


    def run(self):
        """main loop"""
        while not self.done:
            self.channel.process(blocking=1)

    # event handler

    def quit(self, event):
        self.done = 1

    def playbackinfochanged(self, event):
        # this is called by the networkchannel, so it should be (and is) thread safe
        event.playerid = self.id
        hub.hub.notify(event)

    def playerevent(self, event):
        # we have to copy the event, because another thread may also access it
        event = copy.copy(event)
        event.playerid = self.remoteplayerid
        self.networkchannel.notify(event)

    def playlistevent(self, event):
        self.networkchannel.notify(event)

    def playlistchanged(self, event):
        hub.hub.notify(event)

    # request handler

    def playlistgetcontents(self, request):
        return self.networkchannel.request(request)

==> pytone_2.1.3.orig.tar.gz: PyTone-2.1.3/src/services/players/remote.py <==
# -*- coding: ISO-8859-1 -*-

# Copyright (C) 2003, 2004 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyTone; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import copy, threading
import hub, events, requests
import network

class player(threading.Thread):
    def __init__(self, id, server, port):
        threading.Thread.__init__(self)
        self.id = id
        self.server = server
        self.port = port
        self.remoteplayerid = "main"

        # as independent thread, we want our own event channel
        self.channel = hub.newchannel()

        self.networkchannel = network.tcpclientchannel(self.server, self.port)
        #self.networkchannel.transmit(events.updatesong)
        #self.networkchannel.transmit(events.updatealbum)
        #self.networkchannel.transmit(events.updateartist)
        #self.networkchannel.transmit(events.playlistaddsong)
        self.networkchannel.subscribe(events.playbackinfochanged, self.playbackinfochanged)

        # for playlists
        self.networkchannel.subscribe(events.playlistchanged, self.playlistchanged)
        self.networkchannel.start()

        self.done = False

        # we are only servants of higher powers
        self.setDaemon(1)

        # provide player service
        self.channel.subscribe(events.playerevent, self.playerevent)
        # self.channel.subscribe(events.nextsong, self.playerevents)
        
        # we also provide a playlist service
        self.channel.subscribe(events.playlistevent, self.playlistevent)
        self.channel.supply(requests.playlistgetcontents, self.playlistgetcontents)
        
        self.channel.subscribe(events.quit, self.quit)


    def run(self):
        """main loop"""
        while not self.done:
            self.channel.process(blocking=True)

    # event handler

    def quit(self, event):
        self.done = True

    def playbackinfochanged(self, event):
        # this is called by the networkchannel, so it should be (and is) thread safe
        event.playerid = self.id
        hub.notify(event)

    def playerevent(self, event):
        # we have to copy the event, because another thread may also access it
        event = copy.copy(event)
        event.playerid = self.remoteplayerid
        self.networkchannel.notify(event)

    def playlistevent(self, event):
        self.networkchannel.notify(event)

    def playlistchanged(self, event):
        hub.notify(event)

    # request handler

    def playlistgetcontents(self, request):
        return self.networkchannel.request(request)
